DogLandmarkType enum

Dog face landmark types based on the DogFLW dataset topology.

46 landmarks covering ear contours, eyes, nose bridge, nose ring, and mouth/chin contour.

Inheritance
Available extensions

Values

leftEar0 → const DogLandmarkType

Left ear contour point 0 (index 0).

rightEar0 → const DogLandmarkType

Right ear contour point 0 (index 1).

leftEar1 → const DogLandmarkType

Left ear contour point 1 (index 2).

rightEar1 → const DogLandmarkType

Right ear contour point 1 (index 3).

leftEar2 → const DogLandmarkType

Left ear contour point 2 (index 4).

rightEar2 → const DogLandmarkType

Right ear contour point 2 (index 5).

leftEar3 → const DogLandmarkType

Left ear contour point 3 (index 6).

rightEar3 → const DogLandmarkType

Right ear contour point 3 (index 7).

leftEar4 → const DogLandmarkType

Left ear contour point 4 (index 8).

rightEar4 → const DogLandmarkType

Right ear contour point 4 (index 9).

leftEar5 → const DogLandmarkType

Left ear contour point 5 (index 10).

rightEar5 → const DogLandmarkType

Right ear contour point 5 (index 11).

leftEar6 → const DogLandmarkType

Left ear contour point 6 (index 12).

rightEar6 → const DogLandmarkType

Right ear contour point 6 (index 13).

noseBridgeTop → const DogLandmarkType

Top of nose bridge (index 14).

noseBridgeBottom → const DogLandmarkType

Bottom of nose bridge / nose tip (index 15).

leftEyeOuter → const DogLandmarkType

Outer corner of left eye (index 16).

rightEyeOuter → const DogLandmarkType

Outer corner of right eye (index 17).

leftEyeTop → const DogLandmarkType

Top of left eye (index 18).

rightEyeTop → const DogLandmarkType

Top of right eye (index 19).

leftEyeInner → const DogLandmarkType

Inner corner of left eye (index 20).

rightEyeInner → const DogLandmarkType

Inner corner of right eye (index 21).

leftEyeBottom → const DogLandmarkType

Bottom of left eye (index 22).

rightEyeBottom → const DogLandmarkType

Bottom of right eye (index 23).

noseRing0 → const DogLandmarkType

Nose ring point 0 (index 24).

noseRing1 → const DogLandmarkType

Nose ring point 1 (index 25).

noseRing2 → const DogLandmarkType

Nose ring point 2 (index 26).

noseRing3 → const DogLandmarkType

Nose ring point 3 (index 27).

noseRing4 → const DogLandmarkType

Nose ring point 4 (index 28).

noseRing5 → const DogLandmarkType

Nose ring point 5 (index 29).

noseRing6 → const DogLandmarkType

Nose ring point 6 (index 30).

noseRing7 → const DogLandmarkType

Nose ring point 7 (index 31).

mouthChin0 → const DogLandmarkType

Mouth/chin contour point 0 (index 32).

mouthChin1 → const DogLandmarkType

Mouth/chin contour point 1 (index 33).

mouthChin2 → const DogLandmarkType

Mouth/chin contour point 2 (index 34).

mouthChin3 → const DogLandmarkType

Mouth/chin contour point 3 (index 35).

mouthChin4 → const DogLandmarkType

Mouth/chin contour point 4 (index 36).

mouthChin5 → const DogLandmarkType

Mouth/chin contour point 5 (index 37).

mouthChin6 → const DogLandmarkType

Mouth/chin contour point 6 (index 38).

mouthChin7 → const DogLandmarkType

Mouth/chin contour point 7 (index 39).

mouthChin8 → const DogLandmarkType

Mouth/chin contour point 8 (index 40).

mouthChin9 → const DogLandmarkType

Mouth/chin contour point 9 (index 41).

mouthChin10 → const DogLandmarkType

Mouth/chin contour point 10 (index 42).

mouthChin11 → const DogLandmarkType

Mouth/chin contour point 11 (index 43).

mouthChin12 → const DogLandmarkType

Mouth/chin contour point 12 (index 44).

mouthChin13 → const DogLandmarkType

Mouth/chin contour point 13 (index 45).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DogLandmarkType>
A constant List of the values in this enum, in order of their declaration.